@@ -7,6 +7,8 @@ import (
 	"errors"
 	"fmt"
 	"os"
+	"regexp"
+	"slices"
 	"sort"
 	"strconv"
 	"strings"
@@ -14,6 +16,7 @@ import (
 
 	"zgo.at/uni/v2/unidata"
 	"zgo.at/zli"
+	"zgo.at/zstd/zmap"
 	"zgo.at/zstd/zstring"
 )
 
@@ -36,7 +39,7 @@ Flags:
     -o, -or        Use "or" when searching instead of "and".
 
 Commands:
-    list           List blocks, categories, or properties.
+    list           List Unicode data such as blocks, categories, etc.
     identify       Identify all the characters in the given strings.
     search         Search description for any of the words.
     print          Print characters by codepoint, category, or block.
@@ -46,7 +49,7 @@ Use "%(prog) help" or "%(prog) -h" for a more detailed help.
 `)
 
 var usage = zli.Usage(zli.UsageHeaders|zli.UsageProgram|zli.UsageTrim, `
-Usage: %(prog) [command] [flags] 
+Usage: %(prog) [command] [flags]
 
 uni queries the unicode database. https://github.com/arp242/uni
 
@@ -63,8 +66,7 @@ Flags:
                              ignoring formatting flags. Use "-format all" to
                              include all columns.
                      table   Output as table; instead of listing the codepoints
-                             on every line use a table. This ignores the
-                             -format flag.
+                             on every line. This ignores the -format flag.
 
     -c, -compact   More compact output; don't print header, "no matches", etc.
                    For json output it uses minified output, and for table it
@@ -75,16 +77,17 @@ Flags:
 
     -p, -pager     Output to $PAGER.
 
-    -o, -or        Use "or" when searching: print if at least one parameter
+    -o, -or        Use "or" when searching: match if at least one parameter
                    matches, instead of only when all parameters match.
 
     -q, -quiet     Backwards-compatible alias for -c/-compact.
     -j, -json      Backwards-compatible alias for -as json
 
 Commands:
-    list [query]     List an overview of blocks, categories, scripts, or
-                     properties. Every name can be abbreviated (i.e. "b" for
-                     "block"). Use "all" to show everything.
+    list [query]     Show an overview of blocks, categories, scripts,
+                     properties, planes, or unicode versions. Every name can be
+                     abbreviated (i.e. "b" for "block"). Use "all" to show
+                     everything.
 
     identify [text]  Identify all the characters in the given arguments.
 
@@ -93,17 +96,19 @@ Commands:
     print [query]    Print characters. The query can be any of the following:
 
                        Codepoint   Specific codepoint, in number formats:
-                                     hexadecimal   U+20, U20, 0x20, x20
+                                     hexadecimal   U+20, U20, 0x20, x20, 20
                                      decimal       0d32
                                      octal         0o40, o40
                                      binary        0b100000
 
                        Range       Range of codepoints, as "start-end" or
                                    "start..end", using the same notation as
-                                   Codepoints. For example:
+                                   Codepoints. These are all identical:
 
                                       U+2042..U+2050
-                                      '0o101 - 0x5a'
+                                      U+2042-U+2050
+                                      2042..2050
+                                      '0o20102 - 0d8272'
 
                        UTF-8       UTF-8 byte sequence, optionally separated by
                                    any combination of '0x', '-', '_', or spaces.
@@ -180,13 +185,20 @@ Commands:
 
                      Note: emojis may not be accurately copied by select & copy
                      in terminals. It's recommended to copy to the clipboard
-                     directly with e.g. xclip.
+                     directly by piping to e.g. xclip.
 
 Format:
     You can use the -format or -f flag to control what to print; placeholders
     are in the form of %(name) or %(name flags), where "name" is a column name
     and "flags" are some flags to control how it's printed.
 
+    %name is a shortcut for %(name l:auto).
+
+    If the format string starts with "+" it will prepend the format string with
+    the character, codepoint, and name. This is an easy way to quickly list
+    properties yo're interested in. For example, "-f +%unicode to quickly get
+    the Unicode version it was introduced. Otherwise it works exactly as below.
+
     The special value "all" includes all columns; this is useful especially
     with json if you want to get all information uni knows about a codepoint
     or emoji.
@@ -194,11 +206,16 @@ Format:
     Flags:
         %(name l:5)     Left-align and pad with 5 spaces
         %(name l:auto)  Left-align and pad to the longest value
-        %(name r:5)     Right-align and pad with 5 spaces
+        %(name r:5)     Right-align and pad with 5 spaces (also supports auto)
         %(name q)       Quote with single quotes, excluding any padding
+        %(name q:")     Quote with "
+        %(name q:[:],)  Quote with [ at the start, and ], at the end
+        %(name Q)       Quote like q, but omit the quotes if the value is empty
+        %(name Q:[:])
         %(name t)       Trim this column if it's longer than the screen width
-        %(name f:C)     Fill this column with character C; especially useful
-                        for numbers: %(bin r:auto f:0)
+        %(name f:C)     Fill this column with character C instead of space when
+                        aligning; useful for numbers: %(bin r:auto f:0)
+        %(name h)       Don't include in header.
 
     Placeholders that work for all commands:
         %(tab)           A literal tab when outputting to a terminal, or four
@@ -207,6 +224,8 @@ Format:
                          with tabs.
 
     Placeholders for identify, search, and print:
+        Placeholder      Description                   Example
+        -----------      -----------                   -------
         %(char)          The literal character         ✓
                          (also see -raw flag)
         %(cpoint)        As codepoint                  U+2713
@@ -217,7 +236,7 @@ Format:
         %(utf8)          As UTF-8                      e2 9c 93
         %(utf16le)       As UTF-16 LE (Windows)        13 27
         %(utf16be)       As UTF-16 BE                  27 13
-        %(html)          HTML entity                   &check;
+        %(html)          HTML entity (name or hex)     &check;
         %(xml)           XML entity                    &#x2713;
         %(json)          JSON escape                   \u2713
         %(keysym)        X11 keysym; can be blank      checkmark
@@ -228,9 +247,14 @@ Format:
         %(props)         Properties, separated by ,    Pattern Syntax
         %(plane)         Plane name                    Basic Multilingual Plane
         %(width)         Character width               Narrow
+        %(cells)         Number of cells it display    1
+                         as, 0, 1, or 2
         %(unicode)       First assigned in Unicode     1.1
         %(wide_padding)  Blank for wide characters,
                          space otherwise; for alignment
+        %(aliases)       Alias names                   factorial, bang
+        %(refs)          Reference other codepoints,   U+221A, U+1F5F8, U+1FBB1
+                         usually similar/alternatives
 
         The default is:
         `+defaultFormat+`
@@ -250,15 +274,15 @@ Format:
 `)
 
 const (
-	defaultFormat = "%(char q l:3)%(wide_padding) %(cpoint l:7) %(dec l:6) %(utf8 l:11) %(html l:10) %(name t) (%(cat t))"
-	allFormat     = "%(char q l:3)%(wide_padding) %(cpoint l:auto) %(width l:auto) %(dec l:auto) %(hex l:auto)" +
-		" %(oct l:auto) %(bin l:auto)" +
-		" %(utf8 l:auto) %(utf16le l:auto) %(utf16be l:auto) %(html l:auto) %(xml l:auto) %(json l:auto)" +
-		" %(keysym l:auto) %(digraph l:auto) %(name l:auto) %(plane l:auto) %(cat l:auto) %(block l:auto)" +
-		" %(script l:auto) %(props l:auto) %(unicode l:auto)"
+	defaultFormat  = "%(char q h l:3)%(wide_padding) %(cpoint h l:7) %(dec l:6) %(utf8 l:11) %(html l:10) %(name t) %(aliases t h Q:[:])"
+	defaultCompact = "%(char q h l:3)%(wide_padding) %(cpoint h l:7) %(name t l:auto)"
+	allFormat      = "%(char q h l:3)%(wide_padding) %(cpoint h l:auto) %width %cells %dec %hex %oct %bin" +
+		" %utf8 %utf16le %utf16be %html %xml %json %keysym %digraph %name %plane %cat %block" +
+		" %script %props %unicode %aliases %refs"
 
-	defaultEmojiFormat = "%(emoji)%(tab)%(name l:auto)  (%(cldr t))"
-	allEmojiFormat     = "%(emoji)%(tab)%(name l:auto) %(group l:auto) %(subgroup l:auto) %(cpoint l:auto) %(cldr l:auto) %(cldr_full)"
+	defaultEmojiFormat  = "%(emoji h)%(tab)%name  %(cldr t Q:[:])"
+	defaultEmojiCompact = "%(emoji h)%(tab)%name"
+	allEmojiFormat      = "%(emoji h)%(tab)%name %group %subgroup %cpoint %cldr %(cldr_full)"
 )
 
 func main() {
@@ -276,18 +300,14 @@ func main() {
 		asF      = flag.String("list", "a", "as")
 		jsonF    = flag.Bool(false, "json", "j")
 	)
-	err := flag.Parse()
-	zli.F(err)
-
+	zli.F(flag.Parse())
 	if versionF.Set() {
 		fmt.Println(version)
 		return
 	}
-
 	if pager.Set() {
 		defer zli.PagerStdout()()
 	}
-
 	if help.Set() {
 		fmt.Fprint(zli.Stdout, usage)
 		return
@@ -310,7 +330,8 @@ func main() {
 		fmt.Fprint(zli.Stdout, usage)
 		return
 	case "version":
-		fmt.Println(version)
+		u := unidata.Unicodes[unidata.UnicodeLatest]
+		fmt.Printf("%s; Unicode %s (%s)\n", version, u.Name, u.Released)
 		return
 	}
 
@@ -320,7 +341,10 @@ func main() {
 		raw   = rawF.Set()
 		args  = flag.Args
 	)
-	if cmd != "list" {
+	if cmd == "print" {
+		args, err = zli.InputOrArgs(args, " \t\n", quiet)
+		zli.F(err)
+	} else if cmd != "list" {
 		args, err = zli.InputOrArgs(args, "", quiet)
 		zli.F(err)
 	}
@@ -336,6 +360,17 @@ func main() {
 			format = allEmojiFormat
 		}
 	}
+	if strings.HasPrefix(formatF.String(), "+") {
+		format = defaultCompact
+		if cmd == "emoji" {
+			format = defaultEmojiCompact
+		}
+		format += " " + formatF.String()[1:]
+	}
+	// Replace %name shortcut with %(name l:auto)
+	format = regexp.MustCompile(`%[a-z0-9-]+`).ReplaceAllStringFunc(format, func(s string) string {
+		return "%(" + s[1:] + " l:auto)"
+	})
 
 	switch cmd {
 	case "list":
@@ -490,23 +525,41 @@ func list(ls []string, as printAs) error {
 		zli.Fatalf("can't use -as table with the list command")
 	}
 
-	if len(ls) == 0 || zstring.Contains(ls, "all") {
-		ls = []string{"blocks", "categories", "scripts", "properties"}
+	if len(ls) == 0 {
+		return errors.New("need at least property to list: blocks, categories, scripts, properties, planes, unicode, or all")
+	}
+	if slices.Contains(ls, "all") {
+		ls = []string{"blocks", "categories", "scripts", "properties", "planes", "unicode"}
 	}
 
 	for i, l := range ls {
-		cmd, err := match(l, "blocks", "categories", "scripts", "properties")
+		cmd, err := match(l, "blocks", "categories", "scripts", "properties", "unicode", "planes")
 		if cmd != "" && len(ls) > 0 && as == printAsList {
 			if i > 0 {
 				fmt.Fprintln(zli.Stdout)
 			}
-			fmt.Fprintf(zli.Stdout, "%s:\n", zstring.UpperFirst(cmd))
+			if len(ls) > 1 {
+				fmt.Fprintf(zli.Stdout, "%s:\n", zstring.UpperFirst(cmd))
+			}
 		}
 
 		switch cmd {
 		case "":
 			zli.Fatalf("list: %s", err)
 
+		case "unicode":
+			for _, k := range zmap.KeysOrdered(unidata.Unicodes)[1:] {
+				u := unidata.Unicodes[k]
+				fmt.Fprintf(zli.Stdout, "%-6s %s\n", u.Name, u.Released)
+			}
+
+		case "planes":
+			for _, k := range zmap.KeysOrdered(unidata.Planes) {
+				p := unidata.Planes[k]
+				s, e := fmt.Sprintf("U+%04X", p.Range[0]), fmt.Sprintf("U+%04X", p.Range[1])
+				fmt.Fprintf(zli.Stdout, "%-7s - %-8s  %s\n", s, e, p.Name)
+			}
+
 		case "blocks":
 			order := make([]struct {
 				Range [2]rune
@@ -532,7 +585,7 @@ func list(ls []string, as printAs) error {
 
 			fmtCp := map[bool]string{true: "%X", false: "% 7X"}[f.json()]
 			for _, b := range order {
-				f.Line(map[string]string{
+				f.Line(0, map[string]string{
 					"from":     fmt.Sprintf(fmtCp, b.Range[0]),
 					"to":       fmt.Sprintf(fmtCp, b.Range[1]),
 					"assigned": strconv.Itoa(assign[b.Name]),
@@ -567,7 +620,7 @@ func list(ls []string, as printAs) error {
 			sort.Slice(order, func(i, j int) bool { return order[i].Const < order[j].Const })
 
 			for _, s := range order {
-				f.Line(map[string]string{
+				f.Line(0, map[string]string{
 					"name":     s.Name,
 					"assigned": strconv.Itoa(assign[s.Const]),
 				})
@@ -617,7 +670,7 @@ func list(ls []string, as printAs) error {
 					comp = strings.Join(in, " | ")
 				}
 
-				f.Line(map[string]string{
+				f.Line(0, map[string]string{
 					"short":       b.ShortName,
 					"name":        b.Name,
 					"assigned":    strconv.Itoa(assign[b.Const]),
@@ -652,7 +705,7 @@ func list(ls []string, as printAs) error {
 			zli.F(err)
 
 			for _, b := range order {
-				f.Line(map[string]string{
+				f.Line(0, map[string]string{
 					"assigned": strconv.Itoa(assign[b.Name]),
 					"name":     b.Name,
 				})
@@ -679,25 +732,17 @@ func identify(ins []string, format string, raw bool, as printAs) error {
 		if !ok {
 			return fmt.Errorf("unknown codepoint: U+%.4X", c) // Should never happen.
 		}
-
-		f.Line(f.toLine(info, raw))
+		f.Line(info.Codepoint, f.toLine(info, raw))
 	}
 	f.Print(zli.Stdout)
 	return nil
 }
 
 func search(args []string, format string, raw bool, as printAs, or bool) error {
-	var na []string
-	for _, a := range args {
-		if a != "" {
-			na = append(na, a)
-		}
-	}
-	args = na
+	args = slices.DeleteFunc(args, func(s string) bool { return s == "" })
 	if len(args) == 0 {
 		return errors.New("search: need search term")
 	}
-
 	for i := range args {
 		args[i] = strings.ToUpper(args[i])
 	}
@@ -709,12 +754,21 @@ func search(args []string, format string, raw bool, as printAs, or bool) error {
 	}
 
 	for _, info := range unidata.Codepoints {
+		hasAlias := func(upperS string) bool {
+			for _, a := range info.Aliases() {
+				if strings.Contains(strings.ToUpper(a), upperS) {
+					return true
+				}
+			}
+			return false
+		}
+
 		m := 0
 		for _, a := range args {
-			if strings.Contains(info.Name(), a) {
+			if strings.Contains(info.Name(), a) || hasAlias(a) {
 				if or {
 					found = true
-					f.Line(f.toLine(info, raw))
+					f.Line(info.Codepoint, f.toLine(info, raw))
 					break
 				}
 				m++
@@ -722,14 +776,14 @@ func search(args []string, format string, raw bool, as printAs, or bool) error {
 		}
 		if !or && m == len(args) {
 			found = true
-			f.Line(f.toLine(info, raw))
+			f.Line(info.Codepoint, f.toLine(info, raw))
 		}
 	}
 
 	if !found {
 		return errNoMatches
 	}
-	f.SortNum("dec")
+	f.SortCodepoint()
 	f.Print(zli.Stdout)
 	return nil
 }
@@ -752,7 +806,10 @@ func print(args []string, format string, raw bool, as printAs) error {
 		return err
 	}
 	for _, a := range args {
-		a = strings.ToLower(a)
+		a = strings.Trim(strings.ToLower(a), ",/")
+		if a == "" {
+			continue
+		}
 
 		// UTF-8
 		if strings.HasPrefix(a, "utf8:") {
@@ -781,14 +838,14 @@ func print(args []string, format string, raw bool, as printAs) error {
 				return fmt.Errorf("multiple characters in sequence %q", a)
 			}
 
-			f.Line(f.toLine(unidata.Codepoints[r], raw))
+			f.Line(r, f.toLine(unidata.Codepoints[r], raw))
 			continue
 		}
 
 		// Print everything.
 		if strings.ToLower(a) == "all" {
 			for _, info := range unidata.Codepoints {
-				f.Line(f.toLine(info, raw))
+				f.Line(info.Codepoint, f.toLine(info, raw))
 			}
 			continue
 		}
@@ -814,7 +871,7 @@ func print(args []string, format string, raw bool, as printAs) error {
 			if !scOk {
 				zli.Fatalf("unknown or ambiguous script: %q", a)
 			}
-		case zstring.HasPrefixes(a, "category:", "cat:"):
+		case zstring.HasPrefixes(a, "category:", "cat:", "c:"):
 			a = a[strings.IndexByte(a, ':')+1:]
 			cat, catOk = unidata.FindCategory(a)
 			if !catOk {
@@ -855,11 +912,11 @@ func print(args []string, format string, raw bool, as printAs) error {
 
 			for _, info := range unidata.Codepoints {
 				if info.Category() == cat {
-					f.Line(f.toLine(info, raw))
+					f.Line(info.Codepoint, f.toLine(info, raw))
 				}
 				for _, incl := range cc.Include {
 					if info.Category() == incl {
-						f.Line(f.toLine(info, raw))
+						f.Line(info.Codepoint, f.toLine(info, raw))
 					}
 				}
 			}
@@ -876,7 +933,7 @@ func print(args []string, format string, raw bool, as printAs) error {
 				for cp := pp[0]; cp <= pp[1]; cp++ {
 					s, ok := unidata.Codepoints[cp]
 					if ok {
-						f.Line(f.toLine(s, raw))
+						f.Line(cp, f.toLine(s, raw))
 					}
 				}
 			}
@@ -893,7 +950,7 @@ func print(args []string, format string, raw bool, as printAs) error {
 			for cp := unidata.Blocks[bl].Range[0]; cp <= unidata.Blocks[bl].Range[1]; cp++ {
 				s, ok := unidata.Codepoints[cp]
 				if ok {
-					f.Line(f.toLine(s, raw))
+					f.Line(cp, f.toLine(s, raw))
 				}
 			}
 			continue
@@ -908,7 +965,7 @@ func print(args []string, format string, raw bool, as printAs) error {
 				for cp := pp[0]; cp <= pp[1]; cp++ {
 					s, ok := unidata.Codepoints[cp]
 					if ok {
-						f.Line(f.toLine(s, raw))
+						f.Line(cp, f.toLine(s, raw))
 					}
 				}
 			}
@@ -941,10 +998,10 @@ func print(args []string, format string, raw bool, as printAs) error {
 
 		for i := start.Codepoint; i <= end.Codepoint; i++ {
 			info, _ := unidata.Find(i)
-			f.Line(f.toLine(info, raw))
+			f.Line(info.Codepoint, f.toLine(info, raw))
 		}
 	}
-	f.SortNum("dec")
+	f.SortCodepoint()
 	f.Print(zli.Stdout)
 	return nil
 }
@@ -964,7 +1021,7 @@ func emoji(args []string, format string, raw bool, as printAs, or bool, tones, g
 		text  string
 	}
 	var (
-		all       = zstring.Contains(args, "all")
+		all       = slices.Contains(args, "all")
 		matchArgs = make([]matchArg, 0, len(args))
 	)
 	if !all {
@@ -995,7 +1052,7 @@ func emoji(args []string, format string, raw bool, as printAs, or bool, tones, g
 				match = strings.Contains(strings.ToLower(e.Name), a.text)
 			default:
 				match = strings.Contains(strings.ToLower(e.Name), a.text) ||
-					zstring.Contains(e.CLDR, a.text)
+					slices.Contains(e.CLDR, a.text)
 			}
 			if match {
 				m++
@@ -1020,7 +1077,7 @@ func emoji(args []string, format string, raw bool, as printAs, or bool, tones, g
 		return err
 	}
 	for _, e := range out {
-		f.Line(map[string]string{
+		f.Line(0, map[string]string{
 			"emoji":    e.String(),
 			"name":     e.Name,
 			"group":    e.Group().String(),
