@@ -75,6 +75,8 @@ const (
 	Unicode14
 	Unicode15
 	Unicode15_1
+	Unicode16
+	Unicode17
 )
 
 // Unicodes is a list of all Unicode versions since 1.1.
@@ -107,5 +109,7 @@ var Unicodes = map[Unicode]struct {
 	Unicode14:     {"14.0", "September, 2021"},
 	Unicode15:     {"15.0", "September, 2022"},
 	Unicode15_1:   {"15.1", "September, 2023"},
-	UnicodeLatest: {"15.1", "September, 2023"},
+	Unicode16:     {"16.0", "September, 2024"},
+	Unicode17:     {"17.0", "September, 2025"},
+	UnicodeLatest: {"17.0", "September, 2025"},
 }
